import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

# class TestFabricClientCore(unittest.TestCase):

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()

   
    def test_graphql_api(self):

        fc = self.fc
        workspace_id = '46425c13-5736-4285-972c-6d034020f3ff'

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")

        graph_ql = fc.create_graphql_api(workspace_id, display_name="graphql" + datetime_str)
        self.assertEqual(graph_ql.display_name, "graphql" + datetime_str)

        graph_qls = fc.list_graphql_apis(workspace_id)
        graph_ql_names = [gql.display_name for gql in graph_qls]
        self.assertGreater(len(graph_qls), 0)
        self.assertIn("graphql" + datetime_str, graph_ql_names)

        gql = fc.get_graphql_api(workspace_id, graphql_api_name="graphql" + datetime_str)
        self.assertIsNotNone(gql.id)
        self.assertEqual(gql.display_name, "graphql" + datetime_str)

        gql2 = fc.update_graphql_api(workspace_id, gql.id, display_name=f"graphql{datetime_str}2", return_item=True)

        gql = fc.get_graphql_api(workspace_id, graphql_api_id=gql.id)
        self.assertEqual(gql.display_name, f"graphql{datetime_str}2")

        status_code = fc.delete_graphql_api(workspace_id, gql.id)
        self.assertEqual(status_code, 200)



import unittest
from dotenv import load_dotenv
from msfabricpysdkcore import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        self.fcc = FabricClientCore()
                  
    def test_tags(self):
        fcc = self.fcc

        tags = fcc.list_tags()

        self.assertIsInstance(tags, list)
        self.assertGreater(len(tags), 0)
        sdk_tag = [tag for tag in tags if tag['displayName'] == 'sdk_tag'][0]
        self.assertIsNotNone(sdk_tag)

        resp = fcc.unapply_tags("05bc5baa-ef02-4a31-ab20-158a478151d3", "a9e59ec1-524b-49b1-a185-37e47dc0ceb9", [sdk_tag["id"]])
        self.assertEqual(resp, 200)
        resp = fcc.apply_tags("05bc5baa-ef02-4a31-ab20-158a478151d3", "a9e59ec1-524b-49b1-a185-37e47dc0ceb9", [sdk_tag["id"]])
        self.assertEqual(resp, 200)





from msfabricpysdkcore.item import Item

class Lakehouse(Item):
    """Class to represent a item in Microsoft Fabric"""

    def __init__(self, id, display_name, type, workspace_id, core_client, properties = None, definition=None, description=""):
        super().__init__(id, display_name, type, workspace_id, core_client, properties, definition, description)

    def from_dict(item_dict, core_client):
        return Lakehouse(id=item_dict['id'], display_name=item_dict['displayName'], type=item_dict['type'], workspace_id=item_dict['workspaceId'],
            properties=item_dict.get('properties', None),
            definition=item_dict.get('definition', None), description=item_dict.get('description', ""), core_client=core_client)

    def list_tables(self):
        """List all tables in the lakehouse"""
        return self.core_client.list_tables(self.workspace_id, self.id)
    
    def load_table(self, table_name, path_type, relative_path,
                    file_extension = None, format_options = None,
                    mode = None, recursive = None, wait_for_completion = True):
        """Load a table in the lakehouse"""
        return self.core_client.load_table(self.workspace_id, self.id, table_name, path_type, relative_path,
                                           file_extension, format_options, mode, recursive, wait_for_completion)
    
    def run_on_demand_table_maintenance(self, execution_data, job_type = "TableMaintenance", wait_for_completion = True):
        """Run on demand table maintenance"""
        return self.core_client.run_on_demand_table_maintenance(self.workspace_id, self.id, execution_data, job_type, wait_for_completion)
    
    def list_livy_sessions(self):
        """List all livy sessions in the lakehouse"""
        return self.core_client.list_lakehouse_livy_sessions(self.workspace_id, self.id)

    def get_livy_session(self, livy_id):
        """Get a livy session in the lakehouse"""
        return self.core_client.get_lakehouse_livy_session(self.workspace_id, self.id, livy_id)
    
    def create_refresh_materialized_lake_view_schedule(self, enabled, configuration):
        """Create a refresh materialized lake view schedule
        Args:
            enabled (bool): Whether the schedule is enabled
            configuration (dict): The configuration of the schedule
        Returns:
            dict: The created schedule
        """
        return self.core_client.create_refresh_materialized_lake_view_schedule(workspace_id=self.workspace_id, lakehouse_id=self.id,
                                                                               enabled=enabled, configuration=configuration)
    
    def delete_refresh_materialized_lake_view_schedule(self, schedule_id):
        """Delete a refresh materialized lake view schedule
        Args:
            schedule_id (str): The ID of the schedule
        Returns:
            int: The status code of the response
        """
        return self.core_client.delete_refresh_materialized_lake_view_schedule(workspace_id=self.workspace_id, lakehouse_id=self.id,
                                                                               schedule_id=schedule_id)

    def run_on_demand_refresh_materialized_lake_view(self, job_type="RefreshMaterializedLakeViews"):
        """Run refresh materialized lake view
        Args:
            job_type (str): The job type
        Returns:
            dict: The operation result or response value
        """
        return self.core_client.run_on_demand_refresh_materialized_lake_view(workspace_id=self.workspace_id, lakehouse_id=self.id, job_type=job_type)

    def update_refresh_materialized_lake_view_schedule(self, schedule_id, enabled, configuration):
        """Update a refresh materialized lake view schedule
        Args:
            schedule_id (str): The ID of the schedule
            schedule_id (str): The ID of the schedule
            enabled (bool): Whether the schedule is enabled
            configuration (dict): The configuration of the schedule
        Returns:
            dict: The updated schedule
        """
        return self.core_client.update_refresh_materialized_lake_view_schedule(workspace_id=self.workspace_id, lakehouse_id=self.id,
                                                                               schedule_id=schedule_id, enabled=enabled,
                                                                               configuration=configuration)


import unittest
from dotenv import load_dotenv
from msfabricpysdkcore import FabricClientCore
from datetime import datetime
load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        self.fcc = FabricClientCore()
                  
    def test_mirrored_azure_databricks_catalog(self):
        fcc = self.fcc

        workspace_id = "05bc5baa-ef02-4a31-ab20-158a478151d3"
        item_id = "eb5a54af-f282-4612-97c1-95120620b5d3"
        connection_id = "f7ac4f29-a70e-4868-87a1-9cdd92eacfa0"

        catalog_name = "unitycatalogdbxsweden"
        schema_name = "testinternal"
        table_name = "internal_customer"

        mirrored_azure_databricks_catalog = fcc.list_mirrored_azure_databricks_catalogs(workspace_id=workspace_id)
        for mirrored_azure_databricks_catalog in mirrored_azure_databricks_catalog:
            if mirrored_azure_databricks_catalog.id != item_id:
                resp = fcc.delete_mirrored_azure_databricks_catalog(workspace_id=workspace_id, mirrored_azure_databricks_catalog_id=mirrored_azure_databricks_catalog.id)
                self.assertEqual(resp, 200)

        mirrored_azure_databricks_catalog_definition = fcc.get_mirrored_azure_databricks_catalog_definition(workspace_id=workspace_id, mirrored_azure_databricks_catalog_id=item_id)
        self.assertIn("definition", mirrored_azure_databricks_catalog_definition)
        definition = mirrored_azure_databricks_catalog_definition["definition"]

        date_str = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
        date_str = date_str.replace(" ", "T").replace(":", "").replace("-", "")
        date_str = f"copyjob{date_str}"

        mirrored_azure_databricks_catalog_new = fcc.create_mirrored_azure_databricks_catalog(workspace_id=workspace_id, display_name=date_str, definition=definition)

        self.assertEqual(mirrored_azure_databricks_catalog_new.display_name, date_str)

        mirrored_azure_databricks_catalog_get = fcc.get_mirrored_azure_databricks_catalog(workspace_id=workspace_id, mirrored_azure_databricks_catalog_id=mirrored_azure_databricks_catalog_new.id)
        self.assertEqual(mirrored_azure_databricks_catalog_get.display_name, date_str)

        mirrored_azure_databricks_catalog = fcc.list_mirrored_azure_databricks_catalogs(workspace_id=workspace_id)
        self.assertEqual(len(mirrored_azure_databricks_catalog), 2)

        date_str_updated = date_str + "_updated"
        mirrored_azure_databricks_catalog_updated = fcc.update_mirrored_azure_databricks_catalog(workspace_id=workspace_id, mirrored_azure_databricks_catalog_id=mirrored_azure_databricks_catalog_new.id, display_name=date_str_updated, return_item=True)
        self.assertEqual(mirrored_azure_databricks_catalog_updated.display_name, date_str_updated)

        mirrored_azure_databricks_catalog_updated = fcc.update_mirrored_azure_databricks_catalog_definition(workspace_id=workspace_id, mirrored_azure_databricks_catalog_id=mirrored_azure_databricks_catalog_new.id, definition=definition)
        self.assertEqual(mirrored_azure_databricks_catalog_updated.status_code, 200)

        for mirrored_azure_databricks_catalog in mirrored_azure_databricks_catalog:
            if mirrored_azure_databricks_catalog.id != item_id:
                resp = fcc.delete_mirrored_azure_databricks_catalog(workspace_id=workspace_id, mirrored_azure_databricks_catalog_id=mirrored_azure_databricks_catalog.id)
                self.assertEqual(resp, 200)

        catalogs = fcc.discover_mirrored_azure_databricks_catalogs(workspace_id=workspace_id, databricks_workspace_connection_id=connection_id)
        self.assertEqual(len([cat["name"] for cat in catalogs if cat["name"] == catalog_name]), 1)

        schemas = fcc.discover_mirrored_azure_databricks_catalog_schemas(workspace_id=workspace_id, catalog_name=catalog_name, databricks_workspace_connection_id=connection_id)
        self.assertEqual(len([cat["name"] for cat in schemas if cat["name"] == schema_name]), 1)

        tables = fcc.discover_mirrored_azure_databricks_catalog_tables(workspace_id=workspace_id, catalog_name=catalog_name, schema_name=schema_name, databricks_workspace_connection_id=connection_id)
        self.assertEqual(len([cat["name"] for cat in tables if cat["name"] == table_name]), 1)

        status = fcc.refresh_mirrored_azure_databricks_catalog_metadata(workspace_id=workspace_id,
                                                               item_id= item_id, wait_for_completion=False)
        self.assertEqual(status, 202)
        












import unittest
from dotenv import load_dotenv
from msfabricpysdkcore import FabricClientCore
from datetime import datetime
load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        self.fcc = FabricClientCore()
                  
    def test_maps(self):
        fcc = self.fcc

        workspace_id = "05bc5baa-ef02-4a31-ab20-158a478151d3"
        item_id = "9dcf0419-0f08-4cf4-b282-7a0272d02ff0"

        maps = fcc.list_maps(workspace_id=workspace_id)
        for map in maps:
            if map.id != item_id:
                resp = fcc.delete_map(workspace_id=workspace_id, map_id=map.id)
                self.assertEqual(resp, 200)

        map_definition = fcc.get_map_definition(workspace_id=workspace_id, map_id=item_id)
        self.assertIn("definition", map_definition)
        definition = map_definition["definition"]

        date_str = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
        date_str = date_str.replace(" ", "T").replace(":", "").replace("-", "")
        date_str = f"map{date_str}"

        map_new = fcc.create_map(workspace_id=workspace_id, display_name=date_str, definition=definition)

        self.assertEqual(map_new.display_name, date_str)

        map_get = fcc.get_map(workspace_id=workspace_id, map_id=map_new.id)
        self.assertEqual(map_get.display_name, date_str)

        maps = fcc.list_maps(workspace_id=workspace_id)
        self.assertEqual(len(maps), 2)

        date_str_updated = date_str + "_updated"
        map_updated = fcc.update_map(workspace_id=workspace_id, map_id=map_new.id, display_name=date_str_updated, return_item=True)
        self.assertEqual(map_updated.display_name, date_str_updated)

        map_updated = fcc.update_map_definition(workspace_id=workspace_id, map_id=map_new.id, definition=definition)
        self.assertEqual(map_updated.status_code, 200)

        for map in maps:
            if map.id != item_id:
                resp = fcc.delete_map(workspace_id=workspace_id, map_id=map.id)
                self.assertEqual(resp, 200)










import unittest
from dotenv import load_dotenv
from msfabricpysdkcore import FabricClientCore
from datetime import datetime

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        self.fcc = FabricClientCore()
                  
    def test_folders(self):
        fcc = self.fcc

        workspace_id = "05bc5baa-ef02-4a31-ab20-158a478151d3"
        folder_id = "d4f3a9fb-6975-4f5c-9c6b-ca205280966f"
        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        display_name = f"sdk_folder_{datetime_str}"

        folder = fcc.create_folder(workspace_id=workspace_id, display_name=display_name, parent_folder_id=folder_id)
        self.assertIsNotNone(folder)
        self.assertEqual(folder.display_name, display_name)

        folder_ = fcc.get_folder(workspace_id=workspace_id, folder_id=folder.id)
        self.assertEqual(folder.id, folder_.id)

        folders = fcc.list_folders(workspace_id=workspace_id)
        folders = [folder for folder in folders if folder.display_name == display_name]
        self.assertGreater(len(folders), 0)

        folder = fcc.update_folder(workspace_id=workspace_id, folder_id=folder.id, display_name=f"sdk_sub_folder_updated_{datetime_str}")
        self.assertEqual(folder.display_name, f"sdk_sub_folder_updated_{datetime_str}")

        folder = fcc.move_folder(workspace_id=workspace_id, folder_id=folder.id)
        self.assertEqual(folder.display_name, f"sdk_sub_folder_updated_{datetime_str}")
        self.assertEqual(folder.parent_folder_id, "")

        folders = fcc.list_folders(workspace_id=workspace_id)

        for f in folders:
            if f.display_name != "sdk_folder":
                f.delete()

        folders = fcc.list_folders(workspace_id=workspace_id)
        self.assertEqual(len(folders), 1)












import unittest
from dotenv import load_dotenv
from msfabricpysdkcore import FabricClientAdmin

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        self.fca = FabricClientAdmin()
                  
    def test_admin_api(self):
        fca = self.fca

        user_id = '1dc64c6e-7a10-4ea9-8488-85d0739a377d'

        # List workspaces
        ws = fca.list_workspaces(name="testitems")[0]

        self.assertEqual(ws.name, "testitems")

        # Get workspace
        ws_clone = fca.get_workspace(workspace_id=ws.id)

        self.assertEqual(ws.id, ws_clone.id)

        # Discover git connections 
      
        git_connections = fca.discover_git_connections()

        self.assertGreater(len(git_connections), 0)

        git_conn = [g for g in git_connections if g['workspaceId'] == '63aa9e13-4912-4abe-9156-8a56e565b7a3'][0]
        self.assertEqual(git_conn['gitProviderDetails']['ownerName'], 'DaSenf1860')

        # List workspace access details

        ws_access = fca.list_workspace_access_details(ws.id)
        principials = ws_access["accessDetails"]
        principials_ids = [p["principal"]["id"] for p in principials]
        self.assertIn(user_id, principials_ids)

        # Get access entities

        access_entities = fca.list_access_entities(user_id, type="Notebook")
        self.assertGreater(len(access_entities), 0)

        # List tenant settings
    
        settings = fca.list_tenant_settings()
        monitoring_setting = [setting for setting in settings if setting['settingName'] == 'PlatformMonitoringTenantSetting'][0]

        self.assertIsNotNone(monitoring_setting)
 
        # List tenant settings capacity overrides
    
        settings_capa = fca.list_capacities_tenant_settings_overrides()
        setting = [s for s in settings_capa if s['id'] == '9E7E757D-D567-4FB3-BC4F-D230AABF2A00']

        self.assertGreater(len(setting), 0)

 
        # List tenant settings overrides on domains

        domain_overrides = fca.list_domain_tenant_settings_overrides()
        len(domain_overrides) == 0 
        self.assertEqual(len(domain_overrides), 0)

        # List tenant settings overrides on workspaces

        workspace_overrides = fca.list_workspace_tenant_settings_overrides()
        wover = [w for w in workspace_overrides if w["id"] == "192333b2-5f89-4da5-ae69-64a3ee4c649c"]
        self.assertIsNotNone(wover)

        # Update tenant settings

        if monitoring_setting["enabled"] == False:
            changed_settings = fca.update_tenant_setting("PlatformMonitoringTenantSetting", enabled=True)
            "tenantSettings" in changed_settings and len(changed_settings["tenantSettings"]) > 0 and changed_settings["tenantSettings"][0]["enabled"] == True
        else: 
            changed_settings = fca.update_tenant_setting("PlatformMonitoringTenantSetting", enabled=False)
            "tenantSettings" in changed_settings and len(changed_settings["tenantSettings"]) > 0 and changed_settings["tenantSettings"][0]["enabled"] == False



        # Update tenant settings capacity overrides

 
        enabledSecurityGroups = [{'graphId': '73ba0244-b701-41ed-96d9-79917b74f5f8', 'name': 'fabricadmins'}]
        excludedSecurityGroups = [{'graphId': '16450670-829a-4b70-b80e-6524eea067cb', 'name': 'fabricuser'}]
        feedback = fca.update_capacity_tenant_setting_override("9e7e757d-d567-4fb3-bc4f-d230aabf2a00",
                                                    "PlatformMonitoringTenantSetting",
                                                    enabled=True,
                                                    excluded_security_groups=excludedSecurityGroups,
                                                    enabled_security_groups=enabledSecurityGroups)
        
        
        # List tenant settings overrides by capacity id
 
        settings_capa = fca.list_capacity_tenant_settings_overrides_by_capacity_id("9e7e757d-d567-4fb3-bc4f-d230aabf2a00")
        setting = [s for s in settings_capa if s['settingName'] == 'PlatformMonitoringTenantSetting']

        self.assertGreater(len(setting), 0)

        # Update tenant settings capacity overrides

        status_code = fca.delete_capacity_tenant_setting_override("9e7e757d-d567-4fb3-bc4f-d230aabf2a00", "PlatformMonitoringTenantSetting")

        self.assertEqual(status_code, 200)

        settings = [set for set in fca.list_capacity_tenant_settings_overrides_by_capacity_id("9e7e757d-d567-4fb3-bc4f-d230aabf2a00") if set["settingName"] == "PlatformMonitoringTenantSetting"]

        self.assertEqual(len(settings), 0)

        self.assertIn("overrides", feedback)
        self.assertGreater(len(feedback["overrides"]), 0)
        self.assertEqual(feedback["overrides"][0]["enabled"], True)

 





        # List items

        item_list = fca.list_items(workspace_id=ws.id)
        self.assertGreater(len(item_list), 0)

        # Get item

        item = fca.get_item(workspace_id=ws.id, item_id=item_list[0].id)
        self.assertEqual(item.id, item_list[0].id)

        # Get item access details

        item_access = fca.list_item_access_details(workspace_id=ws.id, item_id=item_list[0].id)
        principials = item_access["accessDetails"]

        principials_ids = [p["principal"]["id"] for p in principials]

        self.assertIn(user_id, principials_ids)


    def test_labels(self):

        fca = self.fca

        items = [{"id": "e79d7a0e-1741-4ddf-a705-b861f2775f97", "type": "Lakehouse"}]
        label_id = "defa4170-0d19-0005-0007-bc88714345d2"
        resp = fca.bulk_set_labels(items=items, label_id=label_id)
        self.assertEqual(resp["itemsChangeLabelStatus"][0]["status"], "Succeeded")
        resp = fca.bulk_remove_labels(items=items)
        self.assertEqual(resp["itemsChangeLabelStatus"][0]["status"], "Succeeded")

    def test_admin_external_data_shares(self):

        fca = self.fca

        data_shares = fca.list_external_data_shares()
        ws_id = "05bc5baa-ef02-4a31-ab20-158a478151d3"

        data_shares = [d for d in data_shares if d['workspaceId'] == ws_id]

        self.assertGreater(len(data_shares), 0)
        # fca.revoke_external_data_share(external_data_share_id = data_shares[0]['id'], 
        #                                item_id = data_shares[0]['itemId'], 
        #                                workspace_id = data_shares[0]['workspaceId'])
        # data_shares = fca.list_external_data_shares()

        # data_shares = [d for d in data_shares if d['workspaceId'] == ws_id]

        # self.assertEqual(data_shares[0]['status'], 'Revoked')


import unittest
from dotenv import load_dotenv
from msfabricpysdkcore import FabricClientCore
from datetime import datetime
load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        self.fcc = FabricClientCore()
                  
    def test_dataflows(self):
        fcc = self.fcc

        workspace_id = "05bc5baa-ef02-4a31-ab20-158a478151d3"
        item_id = "8bc6f2f1-2ef9-4dc1-ab47-f55aa90e4088"


        resp = fcc.discover_dataflow_parameters(workspace_id, item_id)

        self.assertIsInstance(resp, list)
        self.assertGreater(len(resp), 0)

        for param in resp:
            self.assertIn("type", param)
            self.assertIn("name", param)
            self.assertIn("description", param)
            self.assertIn("isRequired", param)
            self.assertIn("defaultValue", param)

        dataflows = fcc.list_dataflows(workspace_id=workspace_id)
        for dataflow in dataflows:
            if dataflow.id != item_id:
                resp = fcc.delete_dataflow(workspace_id=workspace_id, dataflow_id=dataflow.id)
                self.assertEqual(resp, 200)

        dataflow_definition = fcc.get_dataflow_definition(workspace_id=workspace_id, dataflow_id=item_id)
        self.assertIn("definition", dataflow_definition)
        definition = dataflow_definition["definition"]

        date_str = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
        date_str = date_str.replace(" ", "T").replace(":", "").replace("-", "")
        date_str = f"dataflow{date_str}"

        dataflow_new = fcc.create_dataflow(workspace_id=workspace_id, display_name=date_str, definition=definition)

        self.assertEqual(dataflow_new.display_name, date_str)

        dataflow_get = fcc.get_dataflow(workspace_id=workspace_id, dataflow_id=dataflow_new.id)
        self.assertEqual(dataflow_get.display_name, date_str)

        dataflows = fcc.list_dataflows(workspace_id=workspace_id)
        self.assertEqual(len(dataflows), 2)

        date_str_updated = date_str + "_updated"
        dataflow_updated = fcc.update_dataflow(workspace_id=workspace_id, dataflow_id=dataflow_new.id, display_name=date_str_updated, return_item=True)
        self.assertEqual(dataflow_updated.display_name, date_str_updated)

        dataflow_updated = fcc.update_dataflow_definition(workspace_id=workspace_id, dataflow_id=dataflow_new.id, definition=definition)
        self.assertEqual(dataflow_updated.status_code, 200)

        for dataflow in dataflows:
            if dataflow.id != item_id:
                resp = fcc.delete_dataflow(workspace_id=workspace_id, dataflow_id=dataflow.id)
                self.assertEqual(resp, 200)










import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        self.item_name = "testitem" + datetime_str
        self.item_type = "Notebook"


    def test_warehouses(self):

        fc = self.fc
        workspace_id = '05bc5baa-ef02-4a31-ab20-158a478151d3'

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        warehouse1 = f"wh{datetime_str}"
        warehouse = fc.create_warehouse(workspace_id, display_name=warehouse1)
        self.assertIsNotNone(warehouse.id)

        warehouses = fc.list_warehouses(workspace_id)
        warehouse_names = [wh.display_name for wh in warehouses]
        self.assertGreater(len(warehouses), 0)
        self.assertIn(warehouse1, warehouse_names)

        warehouse = fc.get_warehouse(workspace_id, warehouse_name=warehouse1)
        self.assertIsNotNone(warehouse.id)
        self.assertEqual(warehouse.display_name, warehouse1)

        warehouse2 = fc.update_warehouse(workspace_id, warehouse.id, display_name=f"{warehouse1}2", return_item=True)
        warehouse = fc.get_warehouse(workspace_id, warehouse_id=warehouse.id)
        self.assertEqual(warehouse.display_name, f"{warehouse1}2")
        self.assertEqual(warehouse.id, warehouse2.id)

        status_code = fc.delete_warehouse(workspace_id, warehouse.id)
        self.assertEqual(status_code, 200)
    
    def test_other_warehouse_stuff(self):
        fcc = self.fc
        workspace_id = "05bc5baa-ef02-4a31-ab20-158a478151d3"
        item_id = "e4655180-815b-4339-984b-213a23524685"

        resp = fcc.get_warehouse_connection_string(workspace_id, item_id)

        self.assertIn('connectionString', resp)
        self.assertIsInstance(resp['connectionString'], str)


        resp = fcc.list_warehouse_restore_points(workspace_id, item_id)
        self.assertGreater(len(resp), 0)
        for rp in resp:
            if rp['id'] != "1760452482000" and rp['creationMode'] != 'SystemCreated':
                rp_to_delete = rp['id']
                break

        resp = fcc.create_warehouse_restore_point(workspace_id, item_id, "my second restore point", wait_for_completion=False)
        
        self.assertIn(resp.status_code, [200, 201, 202])

        resp = fcc.get_warehouse_restore_point(workspace_id, item_id, "1760452482000")
        self.assertEqual(resp, {
            'id': '1760452482000',
            'displayName': 'my first restore point',
            'description': '',
        })

        resp = fcc.update_warehouse_restore_point(workspace_id, item_id, rp_to_delete, description="updated description")

        self.assertEqual(resp['description'], "updated description")
        resp = fcc.delete_warehouse_restore_point(workspace_id, item_id, rp_to_delete)
        self.assertEqual(resp.status_code, 200)

        resp = fcc.restore_warehouse_to_restore_point(workspace_id, item_id, "1760452482000")
        self.assertIn(resp.status_code, [200, 201, 202])

        audit_settings = fcc.get_warehouse_sql_audit_settings(workspace_id=workspace_id, warehouse_id=item_id)

        self.assertIn("state", audit_settings)
        self.assertIn("retentionDays", audit_settings)
        self.assertIn("auditActionsAndGroups", audit_settings)

        respo = fcc.update_warehouse_sql_audit_settings(workspace_id=workspace_id, warehouse_id=item_id,
                                               state="Enabled", retention_days=10)
        self.assertEqual(respo.status_code, 200)

        actionsandgroups = ["SUCCESSFUL_DATABASE_AUTHENTICATION_GROUP",  "FAILED_DATABASE_AUTHENTICATION_GROUP",  "BATCH_COMPLETED_GROUP"]

        respo = fcc.set_warehouse_audit_actions_and_groups(workspace_id=workspace_id, warehouse_id=item_id,
                                                      set_audit_actions_and_groups_request=actionsandgroups)
        self.assertEqual(respo.status_code, 200)
        


if __name__ == "__main__":
    unittest.main()


import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()

    def test_workspace_managed_private_endpoints(self):
                    
        fc = self.fc
        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        workspace_id = '05bc5baa-ef02-4a31-ab20-158a478151d3'

        mpes = fc.list_workspace_managed_private_endpoints(workspace_id=workspace_id)

        if len(mpes) > 0:

            for mpe in mpes:
                status_code = fc.delete_workspace_managed_private_endpoint(workspace_id=workspace_id,
                                                                        managed_private_endpoint_id=mpe["id"])
                self.assertEqual(status_code, 200)
            sleep(60)

        mpe = fc.create_workspace_managed_private_endpoint(workspace_id=workspace_id,
                                                           name=f'testmpe{datetime_str}',
                                                           target_private_link_resource_id='/subscriptions/c77cc8fc-43bb-4d44-bdc5-6e20511ed2a8/resourceGroups/fabricdemo/providers/Microsoft.Storage/storageAccounts/publicfabricdemo9039',
                                                           target_subresource_type='dfs',
                                                           request_message='testmessage')

        mpes = fc.list_workspace_managed_private_endpoints(workspace_id=workspace_id)

        self.assertIsNotNone(mpes)
        self.assertGreater(len(mpes), 0)

        mpe2 = fc.get_workspace_managed_private_endpoint(workspace_id=workspace_id,
                                                         managed_private_endpoint_id=mpe["id"])

        self.assertEqual(mpe2["id"], mpe["id"])

        self.assertIsNotNone(mpe2["connectionState"])
        self.assertIn("targetPrivateLinkResourceId", mpe2)
        self.assertEqual(mpe2["targetPrivateLinkResourceId"], "/subscriptions/c77cc8fc-43bb-4d44-bdc5-6e20511ed2a8/resourceGroups/fabricdemo/providers/Microsoft.Storage/storageAccounts/publicfabricdemo9039")

        for _ in range(0, 20):
            if mpe2["connectionState"]["status"] != "Pending":
                sleep(30)
            else:
                status_code = fc.delete_workspace_managed_private_endpoint(workspace_id=workspace_id,
                                                                           managed_private_endpoint_id=mpe["id"])
                self.assertEqual(status_code, 200)
                break
            mpe2 = fc.get_workspace_managed_private_endpoint(workspace_id=workspace_id,
                                                             managed_private_endpoint_id=mpe["id"])




import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()

    def test_eventstreams(self):

        fcc = self.fc

        workspace_id = "05bc5baa-ef02-4a31-ab20-158a478151d3"
        item_id = "94f4b54b-980b-43f9-8b67-ded8028cf1b9"

        eventstreams = fcc.list_eventstreams(workspace_id=workspace_id)
        for eventstream in eventstreams:
            if eventstream.id != item_id:
                resp = fcc.delete_eventstream(workspace_id=workspace_id, eventstream_id=eventstream.id)
                self.assertEqual(resp, 200)

        eventstream_definition = fcc.get_eventstream_definition(workspace_id=workspace_id, eventstream_id=item_id)
        self.assertIn("definition", eventstream_definition)
        definition = eventstream_definition["definition"]

        date_str = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
        date_str = date_str.replace(" ", "T").replace(":", "").replace("-", "")
        date_str = f"eventstream{date_str}"

        eventstream_new = fcc.create_eventstream(workspace_id=workspace_id, display_name=date_str, definition=definition)

        self.assertEqual(eventstream_new.display_name, date_str)

        eventstream_get = fcc.get_eventstream(workspace_id=workspace_id, eventstream_id=eventstream_new.id)
        self.assertEqual(eventstream_get.display_name, date_str)

        eventstreams = fcc.list_eventstreams(workspace_id=workspace_id)
        self.assertEqual(len(eventstreams), 2)

        date_str_updated = date_str + "_updated"
        eventstream_updated = fcc.update_eventstream(workspace_id=workspace_id, eventstream_id=eventstream_new.id, display_name=date_str_updated, return_item=True)
        self.assertEqual(eventstream_updated.display_name, date_str_updated)

        eventstream_updated = fcc.update_eventstream_definition(workspace_id=workspace_id, eventstream_id=eventstream_new.id, definition=definition)
        self.assertEqual(eventstream_updated.status_code, 200)

        for eventstream in eventstreams:
            if eventstream.id != item_id:
                resp = fcc.delete_eventstream(workspace_id=workspace_id, eventstream_id=eventstream.id)
                self.assertEqual(resp, 200)


import unittest
from dotenv import load_dotenv
from msfabricpysdkcore import FabricClientCore
from datetime import datetime
load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        self.fcc = FabricClientCore()
                  
    def test_sql_endpoint(self):
        fcc = self.fcc

        workspace_id = "05bc5baa-ef02-4a31-ab20-158a478151d3"
        item_id = "d21012a1-f306-4cf1-a21b-f8ae55c17642"

        audit_settings = fcc.get_sql_endpoint_audit_settings(workspace_id=workspace_id, sql_endpoint_id=item_id)

        self.assertIn("state", audit_settings)
        self.assertIn("retentionDays", audit_settings)
        self.assertIn("auditActionsAndGroups", audit_settings)

        respo = fcc.update_sql_endpoint_audit_settings(workspace_id=workspace_id, sql_endpoint_id=item_id,
                                               state="Enabled", retention_days=10)
        self.assertEqual(respo.status_code, 200)

        actionsandgroups = ["SUCCESSFUL_DATABASE_AUTHENTICATION_GROUP",  "FAILED_DATABASE_AUTHENTICATION_GROUP",  "BATCH_COMPLETED_GROUP"]

        respo = fcc.set_sql_endpoint_audit_actions_and_groups(workspace_id=workspace_id, sql_endpoint_id=item_id,
                                                      set_audit_actions_and_groups_request=actionsandgroups)
        self.assertEqual(respo.status_code, 200)
        


import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")


    
    def test_ml_models(self):

        fc = self.fc
        workspace_id = '05bc5baa-ef02-4a31-ab20-158a478151d3'
        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        model_name = "mlm" + datetime_str

        ml_model = fc.create_ml_model(workspace_id, display_name=model_name)
        self.assertEqual(ml_model.display_name, model_name)
        
        ml_models = fc.list_ml_models(workspace_id)
        ml_model_names = [ml.display_name for ml in ml_models]
        self.assertGreater(len(ml_models), 0)
        self.assertIn(model_name, ml_model_names)

        mlm = fc.get_ml_model(workspace_id, ml_model_name=model_name)
        self.assertIsNotNone(mlm.id)
        self.assertEqual(mlm.display_name, model_name)

        mlm2 = fc.update_ml_model(workspace_id=workspace_id,ml_model_id= mlm.id,  description=model_name, return_item=True)

        mlm = fc.get_ml_model(workspace_id, ml_model_id=mlm.id)
        self.assertEqual(mlm.description, model_name)
        self.assertEqual(mlm.id, mlm2.id)

        status_code = fc.delete_ml_model(workspace_id, mlm.id)
        self.assertEqual(status_code, 200)


import unittest
from dotenv import load_dotenv
from msfabricpysdkcore import FabricClientCore
from datetime import datetime
load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        self.fcc = FabricClientCore()
                  
    def test_anomaly_detectors(self):
        fcc = self.fcc

        workspace_id = "05bc5baa-ef02-4a31-ab20-158a478151d3"
        item_id = "9d47b06e-d7c3-40a3-8e6d-6263fb1779a2"

        anomaly_detectors = fcc.list_anomaly_detectors(workspace_id=workspace_id)
        for anomaly_detector in anomaly_detectors:
            if anomaly_detector.id != item_id:
                resp = fcc.delete_anomaly_detector(workspace_id=workspace_id, anomaly_detector_id=anomaly_detector.id)
                self.assertEqual(resp, 200)

        anomaly_detector_definition = fcc.get_anomaly_detector_definition(workspace_id=workspace_id, anomaly_detector_id=item_id)
        self.assertIn("definition", anomaly_detector_definition)
        definition = anomaly_detector_definition["definition"]

        date_str = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
        date_str = date_str.replace(" ", "T").replace(":", "").replace("-", "")
        date_str = f"anomalydetector{date_str}"

        anomaly_detector_new = fcc.create_anomaly_detector(workspace_id=workspace_id, display_name=date_str, definition=definition)

        self.assertEqual(anomaly_detector_new.display_name, date_str)

        anomaly_detector_get = fcc.get_anomaly_detector(workspace_id=workspace_id, anomaly_detector_id=anomaly_detector_new.id)
        self.assertEqual(anomaly_detector_get.display_name, date_str)

        anomaly_detectors = fcc.list_anomaly_detectors(workspace_id=workspace_id)
        self.assertEqual(len(anomaly_detectors), 2)

        date_str_updated = date_str + "_updated"
        anomaly_detector_updated = fcc.update_anomaly_detector(workspace_id=workspace_id, anomaly_detector_id=anomaly_detector_new.id, display_name=date_str_updated, return_item=True)
        self.assertEqual(anomaly_detector_updated.display_name, date_str_updated)

        anomaly_detector_updated = fcc.update_anomaly_detector_definition(workspace_id=workspace_id, anomaly_detector_id=anomaly_detector_new.id, definition=definition)
        self.assertEqual(anomaly_detector_updated.status_code, 200)

        for anomaly_detector in anomaly_detectors:
            if anomaly_detector.id != item_id:
                resp = fcc.delete_anomaly_detector(workspace_id=workspace_id, anomaly_detector_id=anomaly_detector.id)
                self.assertEqual(resp, 200)










import unittest
from dotenv import load_dotenv
from msfabricpysdkcore import FabricClientCore
from datetime import datetime
load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        self.fcc = FabricClientCore()
                  
    def test_digital_twin_builder(self):
        fcc = self.fcc

        workspace_id = "05bc5baa-ef02-4a31-ab20-158a478151d3"
        item_id = "d7260274-8038-44ec-b096-dec1723931d1"

        digital_twin_builder = fcc.list_digital_twin_builders(workspace_id=workspace_id)
        for digital_twin_builder in digital_twin_builder:
            if digital_twin_builder.id != item_id:
                resp = fcc.delete_digital_twin_builder(workspace_id=workspace_id, digital_twin_builder_id=digital_twin_builder.id)
                self.assertEqual(resp, 200)

        digital_twin_builder_definition = fcc.get_digital_twin_builder_definition(workspace_id=workspace_id, digital_twin_builder_id=item_id)
        self.assertIn("definition", digital_twin_builder_definition)
        definition = digital_twin_builder_definition["definition"]

        date_str = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
        date_str = date_str.replace(" ", "T").replace(":", "").replace("-", "")
        date_str = f"copyjob{date_str}"

        digital_twin_builder_new = fcc.create_digital_twin_builder(workspace_id=workspace_id, display_name=date_str, definition=definition)

        self.assertEqual(digital_twin_builder_new.display_name, date_str)

        digital_twin_builder_get = fcc.get_digital_twin_builder(workspace_id=workspace_id, digital_twin_builder_id=digital_twin_builder_new.id)
        self.assertEqual(digital_twin_builder_get.display_name, date_str)

        digital_twin_builder = fcc.list_digital_twin_builders(workspace_id=workspace_id)
        self.assertEqual(len(digital_twin_builder), 2)

        date_str_updated = date_str + "_updated"
        digital_twin_builder_updated = fcc.update_digital_twin_builder(workspace_id=workspace_id, digital_twin_builder_id=digital_twin_builder_new.id, display_name=date_str_updated, return_item=True)
        self.assertEqual(digital_twin_builder_updated.display_name, date_str_updated)

        digital_twin_builder_updated = fcc.update_digital_twin_builder_definition(workspace_id=workspace_id, digital_twin_builder_id=digital_twin_builder_new.id, definition=definition)
        self.assertIn(digital_twin_builder_updated.status_code, [200,202])

        for digital_twin_builder in digital_twin_builder:
            if digital_twin_builder.id != item_id:
                resp = fcc.delete_digital_twin_builder(workspace_id=workspace_id, digital_twin_builder_id=digital_twin_builder.id)
                self.assertEqual(resp, 200)










import unittest
from datetime import datetime
from dotenv import load_dotenv
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        self.fc = FabricClientCore()
        
    def test_spark_job_definitions(self):
        
        fc = self.fc
        workspace_id = '05bc5baa-ef02-4a31-ab20-158a478151d3'

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        spark_job_definition_name = f"sjd{datetime_str}"

        spark_job_definition_w_content = fc.get_spark_job_definition(workspace_id, spark_job_definition_name="helloworld")

        result = fc.run_on_demand_spark_job_definition(workspace_id=workspace_id, 
                                                        spark_job_definition_id=spark_job_definition_w_content.id,
                                                        job_type="sparkjob")
        self.assertIsNotNone(result)
        self.assertEqual(result.job_type, "sparkjob")
        definition = fc.get_spark_job_definition_definition(workspace_id, spark_job_definition_w_content.id)
        
        self.assertIsNotNone(definition)
        self.assertIn("definition", definition)
        definition = definition["definition"]

        spark_job_definition = fc.create_spark_job_definition(workspace_id, display_name=spark_job_definition_name)
        fc.update_spark_job_definition_definition(workspace_id, spark_job_definition.id, definition=definition)
        spark_job_definition = fc.get_spark_job_definition(workspace_id, spark_job_definition_id=spark_job_definition.id)
        self.assertEqual(spark_job_definition.display_name, spark_job_definition_name)
        self.assertIsNotNone(spark_job_definition.definition)

        spark_job_definitions = fc.list_spark_job_definitions(workspace_id)
        spark_job_definition_names = [sjd.display_name for sjd in spark_job_definitions]
        self.assertGreater(len(spark_job_definitions), 0)
        self.assertIn(spark_job_definition_name, spark_job_definition_names)

        sjd = fc.get_spark_job_definition(workspace_id, spark_job_definition_name=spark_job_definition_name)
        self.assertIsNotNone(sjd.id)
        self.assertEqual(sjd.display_name, spark_job_definition_name)

        sjd = fc.update_spark_job_definition(workspace_id, sjd.id, display_name=f"{spark_job_definition_name}2", return_item=True)
        sjd = fc.get_spark_job_definition(workspace_id, spark_job_definition_id=sjd.id)
        self.assertEqual(sjd.display_name, f"{spark_job_definition_name}2")

        status_code = fc.delete_spark_job_definition(workspace_id, sjd.id)
        self.assertEqual(status_code, 200)
